pub struct CodeCallback {
pub code: String,
pub state: String,
}Expand description
Struct that defines how the callback looks like to serialize it better with serde
Fields
code: StringThe code that is returned from the authorization endpoint
state: StringThe state that is returned from the authorization endpoint