pub struct OpenIdDiscoveryResponse {
pub issuer: String,
pub authorization_endpoint: Url,
pub token_endpoint: Url,
pub end_session_endpoint: Option<Url>,
pub jwks_uri: Url,
}Expand description
Fields
issuer: StringThe issuer of the OpenID Connect Provider
The authorization endpoint to start the code flow
token_endpoint: UrlThe token endpoint to exchange the code for a token
end_session_endpoint: Option<Url>The URL to logout the user
jwks_uri: UrlThe jwks uri to load the jwks response from